=========
dbest_sdk
=========


.. image:: https://img.shields.io/pypi/v/dbest_sdk.svg
        :target: https://pypi.python.org/pypi/dbest_sdk

.. image:: https://img.shields.io/travis/PSBPOSAS/dbest-sdk.svg
        :target: https://travis-ci.org/PSBPOSAS/dbest-sdk

.. image:: https://readthedocs.org/projects/dbest-sdk/badge/?version=latest
        :target: https://dbest-sdk.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/PSBPOSAS/dbest-sdk/shield.svg
     :target: https://pyup.io/repos/github/PSBPOSAS/dbest-sdk/
     :alt: Updates



A Python package for remote control of DBEST (drone battery exchanger system for DJI Mavic 2 products)


* Free software: MIT license
* Documentation: https://dbest-sdk.readthedocs.io.


Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
